# F6

The "F6" program is a program designed to work with electronic \ paper accounting of attendance and academic performance of students of secondary professional organizations,\ which generates reports in the form of an extract – "Form 6".

"Form 6" is a paper document reflecting the academic performance and attendance of students,\ which allows you to summarize the overall results of the class/group.